@@ -7,7 +7,7 @@ use vars qw($VERSION $BASE_EXC_CLASS %CLASSES);
 
 BEGIN { $BASE_EXC_CLASS ||= 'Exception::Class::Base'; }
 
-$VERSION = '0.99';
+$VERSION = '1.00';
 
 sub import
 {
@@ -260,7 +260,7 @@ sub as_string
 {
     my $self = shift;
 
-    my $str = $self->{message};
+    my $str = $self->full_message;
     if ( exists $self->{show_trace} ? $self->{show_trace} : $self->Trace )
     {
 	$str .= "\n\n" . $self->trace->as_string;
@@ -269,6 +269,8 @@ sub as_string
     return $str;
 }
 
+sub full_message { $_[0]->{message} }
+
 #
 # The %seen bit protects against circular inheritance.
 #
@@ -539,6 +541,12 @@ Returns a string form of the error message (something like what you'd
 expect from die).  If the class or object is set to show traces then
 then it also includes this in string form (like Carp::confess).
 
+=item * full_message
+
+Called by the C<as_string> method to get the message.  By default,
+this is the same as calling the C<message> method, but may be
+overridden by a subclass.  See below for details.
+
 =back
 
 =head1 OVERLOADING
@@ -554,6 +562,29 @@ actual object.  It also means an application or module could do this:
 and this would probably not break anything (unless someone was
 expecting a different type of exception object from C<die>).
 
+=head1 OVERRIDING THE as_string METHOD
+
+By default, the C<as_string> method simply returns the value
+C<message> or C<error> param plus a stack trace, if one exists.
+
+However, once you add new fields to a subclass, you may want to
+include those fields in the stringified error.
+
+Inside the C<as_string> method, the message (non-stack trace) portion
+of the error is generated by calling the C<full_message> method.  This
+can be easily overridden.  For example:
+
+  sub full_message
+  {
+      my $self = shift;
+
+      my $msg = $self->message;
+
+      $msg .= " and foo was " . $self->foo;
+
+      return $msg;
+  }
+
 =head1 USAGE RECOMMENDATION
 
 If you're creating a complex system that throws lots of different
